$ VERIFY = F$VERIFY(0)
$!-------------
$! CLEARQ.COM
$!-------------
$!	This procedure allows a user to CLEAR entries from a queue.  The
$!	procedure presents queue entries one at a time and allows the user
$!	to remove the entry from the queue via a Y/N query.
$!
$!	If a queue name is passed to the procedure, it is validated.  If no
$!	queue name is passed, it is prompted for.
$!
$!	On Entry:
$!		P1 - Queue name (Optional)
$!		P2 - ALL_JOBS   (Optional: Valid for privileged user only)
$!		                (          Can be abbreviated to ALL.    )
$!
$	ON ERROR THEN GOTO ERROR_TRAP		!Error trap.
$	ON CONTROL_Y THEN GOTO ERROR_TRAP	!User abort trap.
$	STATUS = 1				!Default exit status value.
$	@MSI$UTILITIES:SET_ATTRIBUTES.COM "''F$ENVIRONMENT("PROCEDURE")'"	!Set terminal & process attributes.
$!
$	P1 = F$EDIT(P1, "COLLAPSE, UPCASE")
$	P2 = F$EDIT(P2, "COLLAPSE, UPCASE")
$	IF F$EXTRACT(0, 3, P2) .EQS. "ALL"
$	  THEN
$		IF F$PRIVILEGE("OPER")
$		  THEN
$			P2 = "ALL_JOBS"
$		  ELSE
$			SAY _BELL, "Insufficient privileges to view all jobs"
$			GOTO ERROR_TRAP
$		 ENDIF
$	 ENDIF
$	ERRMSG = ""
$	FOUND = ""
$!
$!	Obtain or validate queue name.  Validated queue name is returned in
$!	global symbol $QUEUE.
$!
$	@MSI$UTILITIES:SELECTQ.COM 'P1'
$	IF $STATUS .EQ. 3 THEN GOTO CANCEL_PROCEDURE
$	IF $QUEUE .EQS. ""
$	  THEN
$		SAY "Queue not found: ", $QUEUE
$		GOTO ERROR_TRAP
$	 ENDIF
$!
$!	CANCEL any outstanding wildcard contexts for F$GETQUE service.
$!
$	TEMP = F$GETQUI("CANCEL_OPERATION")
$!
$!	Get queue information and set context for obtaining job information.
$!
$	IF F$GETQUI("DISPLAY_QUEUE", "QUEUE_CLOSED", $QUEUE)
$	  THEN
$		QSTATUS = "Closed"
$	  ELSE
$		IF F$GETQUI("DISPLAY_QUEUE", "QUEUE_PAUSED", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_PAUSING", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_RESETTING", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_STALLED", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_STOPPED", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_STOPPING", $QUEUE) -
		 .OR. F$GETQUI("DISPLAY_QUEUE", "QUEUE_UNAVAILABLE", $QUEUE)
$		  THEN
$			QSTATUS = "Offline"
$		  ELSE
$			QSTATUS = "Online"
$		 ENDIF
$	 ENDIF
$!
$!	Context for following F$GETQUI commands is set here!!!
$!
$	QDESC = F$GETQUI("DISPLAY_QUEUE", "QUEUE_DESCRIPTION", $QUEUE, "WILDCARD")
$!
$	SAY _BOLD, _REVERSE, _ESC, "[1;1fREMOVE ENTRIES UTILITY", _CANCEL, " (Provided by the wonderful people at MSI)"
$	SAY "Queue: ", _UNDERLINE, $QUEUE, _CANCEL, " <", QDESC, "> ", QSTATUS
$!
$!	This section locates all of the entries on the specified queue
$!	and displays them one at a time.  The user is prompted to remove
$!	each entry.
$!
$ JOB_LOOP:
$	ENTRY = F$GETQUI("DISPLAY_JOB", "ENTRY_NUMBER",, "''P2'")
$	IF ENTRY .EQS. "" THEN GOTO END_PROCEDURE
$	FOUND = 1
$!
$	JOB_STATUS = ""
$	IF F$GETQUI("DISPLAY_JOB", "JOB_ABORTING",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Aborting, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_EXECUTING",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Executing, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_HOLDING",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Holding, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_INACCESSIBLE",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Inaccessible, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_PENDING",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Pending, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_REFUSED",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Refused, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_RETAINED",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Retained, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_STALLED",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Stalled, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_STARTING",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Starting, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_SUSPENDED",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Suspended, "
$	IF F$GETQUI("DISPLAY_JOB", "JOB_TIMED_RELEASE",, "FREEZE_CONTEXT") THEN -
	  JOB_STATUS = JOB_STATUS + "Timed Release, "
$	JOB_STATUS = F$EXTRACT(0, F$LENGTH(JOB_STATUS) - 2, JOB_STATUS)	!Get rid of trailing comma.
$!
$	SAY _ESC, "[3;1f"
$	SAY "  Job:       ", _CEOL, _BOLD, F$GETQUI("DISPLAY_JOB", "JOB_NAME",,"FREEZE_CONTEXT"), _CANCEL
$	SAY "  Entry:     ", _CEOL, _BOLD, ENTRY, _CANCEL
$	SAY "  Owner:     ", _CEOL, _BOLD, F$GETQUI("DISPLAY_JOB", "USERNAME",, "FREEZE_CONTEXT"), _CANCEL
$	SAY "  Submitted: ", _CEOL, _BOLD, F$GETQUI("DISPLAY_JOB", "SUBMISSION_TIME",, "FREEZE_CONTEXT"), _CANCEL
$	SAY "  File:      ", _CEOL, _BOLD, F$GETQUI("DISPLAY_FILE", "FILE_SPECIFICATION",, "FREEZE_CONTEXT"), _CANCEL
$	SAY "  Status:    ", _CEOL, _BOLD, JOB_STATUS, _CANCEL
$!
$	SELECTION = ""
$ RETRY_SELECTION:
$	SAY _BOLD, _ESC, "[12;1f", ERRMSG, _CANCEL
$	SAY _ESC, "[11;1f", _CEOL		!_CLEAR selection line.
$	SAY _ESC, "[11;1fRemove Entry (Y/N) [N]: ", _CANCEL, SELECTION, -
	    _ESC, "[11;29f", _BOLD, "<Ctrl^Z>", _CANCEL, " Quit"
$	ASK "''_ESC'[11;25f" SELECTION
$	SAY _ESC, "[12;1f", _CEOS	!_CLEAR to end of screen
$	ERRMSG = ""			!_CLEAR error message.
$	SELECTION = F$EDIT(SELECTION, "COLLAPSE, UPCASE")
$	IF SELECTION  .EQS. "" THEN SELECTION = "N"
$	IF SELECTION  .NES. "N" .AND. SELECTION .NES. "Y"
$	  THEN
$		ERRMSG = "Invalid selection (Y/N)"
$		GOTO RETRY_SELECTION
$	 ENDIF
$	IF SELECTION  .EQS. "Y"
$	  THEN
$		DELETE /ENTRY='ENTRY'
$!		ERRMSG = "Entry removed: ''ENTRY'"
$	 ENDIF
$	GOTO JOB_LOOP
$!
$ END_PROCEDURE:
$	SAY _ESC, "[1;1f", _CEOS
$	IF .NOT. FOUND
$	  THEN
$		IF P2 .EQS. "ALL_JOBS"
$		  THEN
$			SAY "No entries found in queue ", $QUEUE, " for any user"
$		  ELSE
$			SAY "No entries found in queue ", $QUEUE, " for user ", _USERNAME
$		 ENDIF
$	 ENDIF
$	EXIT 'STATUS' + 0*F$VERIFY(VERIFY)
$!
$ ERROR_TRAP:
$	SAY _BELL
$	SAY "An error or <Ctrl^Y> has aborted this procedure."
$ CHECK_POINT:
$	IF F$MODE().NES."BATCH"
$	  THEN
$		ASK "''_BELL'Enter 0 to exit the procedure: " CHK
$		IF CHK.NES."0" THEN GOTO CHECK_POINT
$	 ENDIF
$ CANCEL_PROCEDURE:
$	STATUS = 3
$	IF F$MODE().NES."BATCH" THEN SET TERMINAL/LINE_EDITING
$	GOTO END_PROCEDURE
$!
$!**************************************************************************
$!*			       DISCLAIMER      				   *
$!*	This software is provided as a service by Migration Specialties	   *
$!*	International (MSI).  This software is provided as is and is 	   *
$!*	neither supported nor warrantied by MSI.  The customer may use	   *
$!*	and modify this software at their own risk.             	   *
$!*			Migration Specialties International		   *
$!*			(719)784-9196, Fax: (719)784-9594          	   *
$!*			No warranties either expressed or implied. 	   *
$!**************************************************************************
